@@ -1,21 +1,21 @@
-import abc
-import typing
+from abc import ABC, abstractmethod
+from typing import Set
 
 from python_dice.interface.constraint.i_constraint import IConstraint
 from python_dice.interface.constraint.i_var_value_constraint import IVarValueConstraint
 
 
-class IConstraintFactory(abc.ABC):
+class IConstraintFactory(ABC):
     @property
-    @abc.abstractmethod
+    @abstractmethod
     def impossible_constraint(self) -> IConstraint:
         pass
 
     @property
-    @abc.abstractmethod
+    @abstractmethod
     def null_constraint(self) -> IConstraint:
         pass
 
-    @abc.abstractmethod
-    def var_value_constraint(self, name: str, values: typing.Set[int]) -> IVarValueConstraint:
+    @abstractmethod
+    def var_value_constraint(self, name: str, values: Set[int]) -> IVarValueConstraint:
         pass
