@@ -1,5 +1,5 @@
-import abc
-import typing
+from abc import ABC, abstractmethod
+from typing import Tuple
 
 from python_dice.interface.expression.i_dice_expression import IDiceExpression
 from python_dice.interface.probability_distribution.i_probability_distribution_state import (
@@ -7,13 +7,13 @@ from python_dice.interface.probability_distribution.i_probability_distribution_s
 )
 
 
-class IPythonDiceParser(abc.ABC):
-    @abc.abstractmethod
+class IPythonDiceParser(ABC):
+    @abstractmethod
     def parse(
         self,
         input_text: str,
         state: IProbabilityDistributionState = None,
-    ) -> typing.Tuple[IDiceExpression, IProbabilityDistributionState,]:
+    ) -> Tuple[IDiceExpression, IProbabilityDistributionState]:
         """
 
         :return: output of pydice program
