@@ -1,18 +1,18 @@
-import abc
+from abc import ABC, abstractmethod
 
 from python_dice.interface.probability_distribution.i_probability_distribution import IProbabilityDistribution
 
 
-class IProbabilityDistributionState(abc.ABC):
-    @abc.abstractmethod
+class IProbabilityDistributionState(ABC):
+    @abstractmethod
     def get_var(self, name: str) -> IProbabilityDistribution:
         pass
 
-    @abc.abstractmethod
+    @abstractmethod
     def has_var(self, name: str) -> bool:
         pass
 
-    @abc.abstractmethod
+    @abstractmethod
     def set_var(
         self,
         name: str,
@@ -20,22 +20,22 @@ class IProbabilityDistributionState(abc.ABC):
     ) -> None:
         pass
 
-    @abc.abstractmethod
+    @abstractmethod
     def get_var_dict(self):
         pass
 
-    @abc.abstractmethod
+    @abstractmethod
     def get_constant(self, name: str) -> int:
         pass
 
-    @abc.abstractmethod
+    @abstractmethod
     def has_constant(self, name: str) -> bool:
         pass
 
-    @abc.abstractmethod
+    @abstractmethod
     def set_constant(self, name: str, value: int) -> None:
         pass
 
-    @abc.abstractmethod
+    @abstractmethod
     def get_constant_dict(self):
         pass
